#line 2 "dvdvml.c"

#line 4 "dvdvml.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer dvdvm_create_buffer
#define yy_delete_buffer dvdvm_delete_buffer
#define yy_flex_debug dvdvm_flex_debug
#define yy_init_buffer dvdvm_init_buffer
#define yy_flush_buffer dvdvm_flush_buffer
#define yy_load_buffer_state dvdvm_load_buffer_state
#define yy_switch_to_buffer dvdvm_switch_to_buffer
#define yyin dvdvmin
#define yyleng dvdvmleng
#define yylex dvdvmlex
#define yylineno dvdvmlineno
#define yyout dvdvmout
#define yyrestart dvdvmrestart
#define yytext dvdvmtext
#define yywrap dvdvmwrap
#define yyalloc dvdvmalloc
#define yyrealloc dvdvmrealloc
#define yyfree dvdvmfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE dvdvmrestart(dvdvmin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int dvdvmleng;

extern FILE *dvdvmin, *dvdvmout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up dvdvmtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up dvdvmtext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via dvdvmrestart()), so that the user can continue scanning by
	 * just pointing dvdvmin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when dvdvmtext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int dvdvmleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow dvdvmwrap()'s to do buffer switches
 * instead of setting up a fresh dvdvmin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void dvdvmrestart (FILE *input_file  );
void dvdvm_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE dvdvm_create_buffer (FILE *file,int size  );
void dvdvm_delete_buffer (YY_BUFFER_STATE b  );
void dvdvm_flush_buffer (YY_BUFFER_STATE b  );
void dvdvmpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void dvdvmpop_buffer_state (void );

static void dvdvmensure_buffer_stack (void );
static void dvdvm_load_buffer_state (void );
static void dvdvm_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER dvdvm_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE dvdvm_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE dvdvm_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE dvdvm_scan_bytes (yyconst char *bytes,int len  );

void *dvdvmalloc (yy_size_t  );
void *dvdvmrealloc (void *,yy_size_t  );
void dvdvmfree (void *  );

#define yy_new_buffer dvdvm_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        dvdvmensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            dvdvm_create_buffer(dvdvmin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        dvdvmensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            dvdvm_create_buffer(dvdvmin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define dvdvmwrap(n) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *dvdvmin = (FILE *) 0, *dvdvmout = (FILE *) 0;

typedef int yy_state_type;

extern int dvdvmlineno;

int dvdvmlineno = 1;

extern char *dvdvmtext;
#define yytext_ptr dvdvmtext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up dvdvmtext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	dvdvmleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 85
#define YY_END_OF_BUFFER 86
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[198] =
    {   0,
        0,    0,   86,   84,   44,   44,   70,   84,   50,   51,
       75,   76,   48,   46,   47,   49,   78,   78,   72,   71,
       67,   45,   65,   83,   53,   83,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   83,   83,   73,   52,   74,   44,   63,    0,
       58,   68,   59,   56,   54,   55,    1,   57,   78,   79,
        0,   66,   62,   64,   83,   61,   83,   83,   83,   83,
       83,   83,   83,   83,   83,   83,   13,   83,   83,   81,
       16,   83,   18,   19,   83,   21,   22,   83,   24,   83,
       27,   83,   83,   83,   83,   83,   83,   82,   83,   83,

       83,   83,   41,   83,   83,   60,   69,    0,   77,    2,
       83,   83,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   15,   83,   83,   83,   83,   26,   28,   83,   83,
       31,   83,   83,   83,   83,   83,   83,   83,   40,   83,
       43,   80,   83,   83,   83,   83,    7,    8,   83,   83,
       11,   83,   14,   17,   20,   23,   25,   29,   83,   83,
       83,   83,   35,   83,   37,   83,   42,    3,    4,    5,
       83,   83,   83,   12,   83,   83,   83,   83,   83,   38,
        6,   83,   83,   83,   32,   33,   34,   83,   83,    9,
       10,   30,   83,   83,   36,   39,    0

    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    1,    1,    6,    7,    1,    8,
        9,   10,   11,    1,   12,    1,   13,   14,   15,   15,
       15,   15,   15,   15,   15,   15,   15,   16,   17,   18,
       19,   20,    1,    1,   21,   21,   21,   21,   21,   21,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
        1,    1,    1,   23,   22,    1,   24,   25,   26,   27,

       28,   29,   30,   31,   32,   33,   34,   35,   36,   37,
       38,   39,   40,   41,   42,   43,   44,   45,   46,   47,
       48,   46,   49,   50,   51,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[52] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    2,    2,    1,    1,    1,    1,    1,
        2,    3,    1,    4,    4,    4,    4,    4,    4,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    1,    1,
        1
    } ;

static yyconst flex_int16_t yy_base[202] =
    {   0,
        0,    0,  225,  226,   50,   52,  205,    0,  204,   49,
      226,  226,  203,  202,  201,   47,   44,   46,  226,  226,
      200,  199,  198,    0,  197,   25,   23,   46,   36,  176,
       67,  185,  169,   44,  184,   37,  170,   49,   61,   79,
       64,  171,  173,  170,  226,   67,  226,   95,  226,    0,
      226,  226,  226,  226,  226,  226,  226,  226,   86,  226,
        0,  226,  226,  226,    0,  226,   76,  180,  178,  162,
      169,  168,  178,  157,  158,  156,    0,  166,  171,   93,
        0,  153,    0,    0,  159,    0,    0,  157,  146,  149,
        0,  165,   76,  147,  152,   79,  150,   97,  162,  154,

      142,  145,    0,  153,  141,  226,  226,  176,    0,    0,
      145,  147,  154,  134,  141,  140,  135,  136,  144,  130,
      127,    0,  131,  129,  123,  123,    0,    0,  120,  134,
        0,  136,  130,  117,  117,  116,  123,  122,    0,  120,
        0,  226,  127,  116,  119,  114,    0,    0,  108,  107,
        0,  101,    0,    0,    0,    0,    0,    0,  107,  109,
      108,  109,    0,  112,    0,  115,    0,    0,    0,    0,
      105,  113,  112,    0,  115,  102,  100,  108,   92,   91,
        0,   81,   78,   82,    0,    0,    0,   81,   87,    0,
        0,    0,   85,   20,    0,    0,  226,  120,  124,  126,

      130
    } ;

static yyconst flex_int16_t yy_def[202] =
    {   0,
      197,    1,  197,  197,  197,  197,  197,  198,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  199,  197,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  197,  197,  197,  197,  197,  200,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      201,  197,  197,  197,  199,  197,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,

      199,  199,  199,  199,  199,  197,  197,  197,  201,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,
      199,  197,  199,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,  199,  199,  199,  199,
      199,  199,  199,  199,  199,  199,    0,  197,  197,  197,

      197
    } ;

static yyconst flex_int16_t yy_nxt[278] =
    {   0,
        4,    5,    6,    7,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   17,   18,   19,   20,   21,   22,   23,
       24,   24,   25,   26,   27,   28,   24,   29,   30,   31,
       24,   32,   33,   24,   34,   35,   36,   37,   38,   24,
       39,   40,   41,   42,   43,   24,   44,   24,   45,   46,
       47,   48,   48,   48,   48,   52,   57,   59,   59,   59,
       59,   67,  196,   69,   89,   58,   70,   53,   68,   71,
       75,   86,   76,   72,   90,   77,   73,   60,   92,   60,
       80,   80,   78,   74,   95,  106,   87,  100,   96,   93,
       61,   94,   98,   98,   81,  101,   48,   48,   97,   59,

       59,  102,  110,  129,   82,  111,   80,   80,  133,   83,
       98,   98,  195,  130,  194,  193,  107,  192,  191,   60,
      134,  190,   99,   50,   50,   65,   65,   65,   65,  108,
      108,  109,  189,  109,  188,  187,  186,  185,  184,  183,
      182,  181,  180,  179,  178,  177,  176,  175,  174,  173,
      172,  171,  170,  169,  168,  167,  166,  165,  164,  163,
      162,  161,  160,  159,  158,  157,  156,  155,  154,  153,
      152,  151,  150,  149,  148,  147,  146,  145,  144,  143,
      142,  141,  140,  139,  138,  137,  136,  135,  132,  131,
      128,  127,  126,  125,  124,  123,  122,  121,  120,  119,

      118,  117,  116,  115,  114,  113,  112,  105,  104,  103,
       91,   88,   85,   84,   79,   66,   64,   63,   62,   56,
       55,   54,   51,   49,  197,    3,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197
    } ;

static yyconst flex_int16_t yy_chk[278] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    5,    6,    6,   10,   16,   17,   17,   18,
       18,   26,  194,   27,   36,   16,   27,   10,   26,   28,
       29,   34,   29,   28,   36,   29,   28,   17,   38,   18,
       31,   31,   29,   28,   39,   46,   34,   41,   39,   38,
       17,   38,   40,   40,   31,   41,   48,   48,   39,   59,

       59,   41,   67,   93,   31,   67,   80,   80,   96,   31,
       98,   98,  193,   93,  189,  188,   46,  184,  183,   59,
       96,  182,   40,  198,  198,  199,  199,  199,  199,  200,
      200,  201,  180,  201,  179,  178,  177,  176,  175,  173,
      172,  171,  166,  164,  162,  161,  160,  159,  152,  150,
      149,  146,  145,  144,  143,  140,  138,  137,  136,  135,
      134,  133,  132,  130,  129,  126,  125,  124,  123,  121,
      120,  119,  118,  117,  116,  115,  114,  113,  112,  111,
      108,  105,  104,  102,  101,  100,   99,   97,   95,   94,
       92,   90,   89,   88,   85,   82,   79,   78,   76,   75,

       74,   73,   72,   71,   70,   69,   68,   44,   43,   42,
       37,   35,   33,   32,   30,   25,   23,   22,   21,   15,
       14,   13,    9,    7,    3,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197,  197,  197,  197,
      197,  197,  197,  197,  197,  197,  197
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int dvdvm_flex_debug;
int dvdvm_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *dvdvmtext;
#line 1 "dvdvml.l"
#line 2 "dvdvml.l"

/*
 * Copyright (C) 2002 Scott Smith (trckjunky@users.sourceforge.net)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

#include "compat.h" /* needed for bool */
#include "dvdvm.h"
#include "dvdvmy.h"


#line 635 "dvdvml.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int dvdvmlex_destroy (void );

int dvdvmget_debug (void );

void dvdvmset_debug (int debug_flag  );

YY_EXTRA_TYPE dvdvmget_extra (void );

void dvdvmset_extra (YY_EXTRA_TYPE user_defined  );

FILE *dvdvmget_in (void );

void dvdvmset_in  (FILE * in_str  );

FILE *dvdvmget_out (void );

void dvdvmset_out  (FILE * out_str  );

int dvdvmget_leng (void );

char *dvdvmget_text (void );

int dvdvmget_lineno (void );

void dvdvmset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int dvdvmwrap (void );
#else
extern int dvdvmwrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( dvdvmtext, dvdvmleng, 1, dvdvmout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( dvdvmin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( dvdvmin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, dvdvmin))==0 && ferror(dvdvmin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(dvdvmin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int dvdvmlex (void);

#define YY_DECL int dvdvmlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after dvdvmtext and dvdvmleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 42 "dvdvml.l"


#line 823 "dvdvml.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! dvdvmin )
			dvdvmin = stdin;

		if ( ! dvdvmout )
			dvdvmout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			dvdvmensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				dvdvm_create_buffer(dvdvmin,YY_BUF_SIZE );
		}

		dvdvm_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of dvdvmtext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 198 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 197 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 44 "dvdvml.l"
{
        bool seen_star = false;
        for (;;)
          {
            const int c = input();
            if (c == EOF)
              {
                fprintf(stderr, "EOF in comment");
                return ERROR_TOK;
              } /*if*/
            if (c == '/' && seen_star)
                break;
            seen_star = c == '*';
          } /*for*/
    }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 60 "dvdvml.l"
{ return _AND_TOK; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 61 "dvdvml.l"
{ return ANGLE_TOK; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 62 "dvdvml.l"
{ return AUDIO_TOK; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 63 "dvdvml.l"
{ return BREAK_TOK; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 64 "dvdvml.l"
{ return BUTTON_TOK; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 65 "dvdvml.l"
{ return CALL_TOK; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 66 "dvdvml.l"
{ return CELL_TOK; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 67 "dvdvml.l"
{ return CHAPTER_TOK; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 68 "dvdvml.l"
{ return COUNTER_TOK; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 69 "dvdvml.l"
{ return ELSE_TOK; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 70 "dvdvml.l"
{ return ENTRY_TOK; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 71 "dvdvml.l"
{ return EQ_TOK; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 72 "dvdvml.l"
{ return EXIT_TOK; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 73 "dvdvml.l"
{ return FPC_TOK; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 74 "dvdvml.l"
{ return GE_TOK; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 75 "dvdvml.l"
{ return GOTO_TOK; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 76 "dvdvml.l"
{ return GT_TOK; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 77 "dvdvml.l"
{ return IF_TOK; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 78 "dvdvml.l"
{ return JUMP_TOK; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 79 "dvdvml.l"
{ return LE_TOK; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 80 "dvdvml.l"
{ return LT_TOK; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 81 "dvdvml.l"
{ return MENU_TOK; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 82 "dvdvml.l"
{ return NE_TOK; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 83 "dvdvml.l"
{ return NEXT_TOK; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 84 "dvdvml.l"
{ return NOT_TOK; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 85 "dvdvml.l"
{ return _OR_TOK; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 86 "dvdvml.l"
{ return PGC_TOK; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 87 "dvdvml.l"
{ return PREV_TOK; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 88 "dvdvml.l"
{ return PROGRAM_TOK; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 89 "dvdvml.l"
{ return PTT_TOK; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 90 "dvdvml.l"
{ return RND_TOK; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 91 "dvdvml.l"
{ return REGION_TOK; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 92 "dvdvml.l"
{ return RESUME_TOK; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 93 "dvdvml.l"
{ return ROOT_TOK; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 94 "dvdvml.l"
{ return SUBTITLE_TOK; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 95 "dvdvml.l"
{ return TAIL_TOK; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 96 "dvdvml.l"
{ return TITLE_TOK; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 97 "dvdvml.l"
{ return TITLESET_TOK; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 98 "dvdvml.l"
{ return TOP_TOK; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 99 "dvdvml.l"
{ return UP_TOK; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 100 "dvdvml.l"
{ return VMGM_TOK; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 101 "dvdvml.l"
{ return XOR_TOK; }
	YY_BREAK
case 44:
/* rule 44 can match eol */
YY_RULE_SETUP
#line 104 "dvdvml.l"
;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 106 "dvdvml.l"
{ return SET_TOK; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 108 "dvdvml.l"
{ return ADD_TOK; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 109 "dvdvml.l"
{ return SUB_TOK; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 110 "dvdvml.l"
{ return MUL_TOK; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 111 "dvdvml.l"
{ return DIV_TOK; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 112 "dvdvml.l"
{ return MOD_TOK; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 113 "dvdvml.l"
{ return BAND_TOK; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 114 "dvdvml.l"
{ return BOR_TOK;  }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 115 "dvdvml.l"
{ return XOR_TOK; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 117 "dvdvml.l"
{ return ADDSET_TOK; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 118 "dvdvml.l"
{ return SUBSET_TOK; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 119 "dvdvml.l"
{ return MULSET_TOK; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 120 "dvdvml.l"
{ return DIVSET_TOK; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 121 "dvdvml.l"
{ return MODSET_TOK; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 122 "dvdvml.l"
{ return ANDSET_TOK; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 123 "dvdvml.l"
{ return ORSET_TOK;  }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 124 "dvdvml.l"
{ return XORSET_TOK; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 126 "dvdvml.l"
{ return EQ_TOK; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 127 "dvdvml.l"
{ return NE_TOK; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 128 "dvdvml.l"
{ return GE_TOK; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 129 "dvdvml.l"
{ return GT_TOK; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 130 "dvdvml.l"
{ return LE_TOK; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 131 "dvdvml.l"
{ return LT_TOK; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 133 "dvdvml.l"
{ return LAND_TOK; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 134 "dvdvml.l"
{ return LOR_TOK; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 135 "dvdvml.l"
{ return NOT_TOK; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 137 "dvdvml.l"
{ return SEMICOLON_TOK; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 138 "dvdvml.l"
{ return COLON_TOK; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 139 "dvdvml.l"
{ return OPENBRACE_TOK; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 140 "dvdvml.l"
{ return CLOSEBRACE_TOK; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 141 "dvdvml.l"
{ return OPENPAREN_TOK; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 142 "dvdvml.l"
{ return CLOSEPAREN_TOK; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 144 "dvdvml.l"
{ sscanf((char *)dvdvmtext,"0x%x",&dvdvmlval.int_val);
          if( dvdvmlval.int_val<0 || dvdvmlval.int_val>=65536 ) {
            fprintf(stderr,"ERR:  Integers must be between 0 and 65535, inclusive (%s)\n",dvdvmtext);
            return ERROR_TOK;
          }
                  return NUM_TOK; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 152 "dvdvml.l"
{ sscanf((char *)dvdvmtext,"%u",&dvdvmlval.int_val);
          if( dvdvmlval.int_val<0 || dvdvmlval.int_val>=65536 ) {
            fprintf(stderr,"ERR:  Integers must be between 0 and 65535, inclusive (%s)\n",dvdvmtext);
            return ERROR_TOK;
          }
                  return NUM_TOK; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 159 "dvdvml.l"
{ sscanf((char *)dvdvmtext,"%u",&dvdvmlval.int_val);
          if( dvdvmlval.int_val<0 || dvdvmlval.int_val>=64 ) {
            fprintf(stderr,"ERR:  Integers must be between 0 and 65535, inclusive (%s)\n",dvdvmtext);
            return ERROR_TOK;
          }
                  dvdvmlval.int_val*=1024;
                  return NUM_TOK; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 167 "dvdvml.l"
{ dvdvmlval.int_val = ((unsigned char *)dvdvmtext)[1] * 256 + ((unsigned char *)dvdvmtext)[2];
                  return NUM_TOK; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 171 "dvdvml.l"
{ sscanf((char *)dvdvmtext+1,"%u",&dvdvmlval.int_val);
                  if( allowallreg ) {
                      if( dvdvmlval.int_val<0 || dvdvmlval.int_val>=16 ) {
                          fprintf(stderr,"ERR:  Can only access g0-g15 (%s)\n",dvdvmtext);
                          return ERROR_TOK;
                      }
                  } else {
                      if( dvdvmlval.int_val<0 || dvdvmlval.int_val>=13 ) {
                          fprintf(stderr,"ERR:  Can only access g0-g12 (%s)\n",dvdvmtext);
                          return ERROR_TOK;
                      }
                  }
          return G_TOK; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 185 "dvdvml.l"
{ sscanf((char *)dvdvmtext+1,"%u",&dvdvmlval.int_val);
          if( dvdvmlval.int_val<0 || dvdvmlval.int_val>23 ) {
            fprintf(stderr,"ERR:  Can only access s0-s23 (%s)\n",dvdvmtext);
            return ERROR_TOK;
          }     
          return S_TOK; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 192 "dvdvml.l"
{ dvdvmlval.str_val = strdup((char *)dvdvmtext);
                  return ID_TOK; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 196 "dvdvml.l"
{ return ERROR_TOK; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 198 "dvdvml.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1377 "dvdvml.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed dvdvmin at a new source and called
			 * dvdvmlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = dvdvmin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( dvdvmwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * dvdvmtext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of dvdvmlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					dvdvmrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			dvdvmrestart(dvdvmin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) dvdvmrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 198 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 198 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 197);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					dvdvmrestart(dvdvmin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( dvdvmwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve dvdvmtext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void dvdvmrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        dvdvmensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            dvdvm_create_buffer(dvdvmin,YY_BUF_SIZE );
	}

	dvdvm_init_buffer(YY_CURRENT_BUFFER,input_file );
	dvdvm_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void dvdvm_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		dvdvmpop_buffer_state();
	 *		dvdvmpush_buffer_state(new_buffer);
     */
	dvdvmensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	dvdvm_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (dvdvmwrap()) processing, but the only time this flag
	 * is looked at is after dvdvmwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void dvdvm_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	dvdvmin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE dvdvm_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) dvdvmalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in dvdvm_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) dvdvmalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in dvdvm_create_buffer()" );

	b->yy_is_our_buffer = 1;

	dvdvm_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with dvdvm_create_buffer()
 * 
 */
    void dvdvm_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		dvdvmfree((void *) b->yy_ch_buf  );

	dvdvmfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a dvdvmrestart() or at EOF.
 */
    static void dvdvm_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	dvdvm_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then dvdvm_init_buffer was _probably_
     * called from dvdvmrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void dvdvm_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		dvdvm_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void dvdvmpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	dvdvmensure_buffer_stack();

	/* This block is copied from dvdvm_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from dvdvm_switch_to_buffer. */
	dvdvm_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void dvdvmpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	dvdvm_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		dvdvm_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void dvdvmensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)dvdvmalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in dvdvmensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)dvdvmrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in dvdvmensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE dvdvm_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) dvdvmalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in dvdvm_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	dvdvm_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to dvdvmlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       dvdvm_scan_bytes() instead.
 */
YY_BUFFER_STATE dvdvm_scan_string (yyconst char * yystr )
{
    
	return dvdvm_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to dvdvmlex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE dvdvm_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) dvdvmalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in dvdvm_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = dvdvm_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in dvdvm_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up dvdvmtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		dvdvmtext[dvdvmleng] = (yy_hold_char); \
		(yy_c_buf_p) = dvdvmtext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		dvdvmleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int dvdvmget_lineno  (void)
{
        
    return dvdvmlineno;
}

/** Get the input stream.
 * 
 */
FILE *dvdvmget_in  (void)
{
        return dvdvmin;
}

/** Get the output stream.
 * 
 */
FILE *dvdvmget_out  (void)
{
        return dvdvmout;
}

/** Get the length of the current token.
 * 
 */
int dvdvmget_leng  (void)
{
        return dvdvmleng;
}

/** Get the current token.
 * 
 */

char *dvdvmget_text  (void)
{
        return dvdvmtext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void dvdvmset_lineno (int  line_number )
{
    
    dvdvmlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see dvdvm_switch_to_buffer
 */
void dvdvmset_in (FILE *  in_str )
{
        dvdvmin = in_str ;
}

void dvdvmset_out (FILE *  out_str )
{
        dvdvmout = out_str ;
}

int dvdvmget_debug  (void)
{
        return dvdvm_flex_debug;
}

void dvdvmset_debug (int  bdebug )
{
        dvdvm_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from dvdvmlex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    dvdvmin = stdin;
    dvdvmout = stdout;
#else
    dvdvmin = (FILE *) 0;
    dvdvmout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * dvdvmlex_init()
     */
    return 0;
}

/* dvdvmlex_destroy is for both reentrant and non-reentrant scanners. */
int dvdvmlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		dvdvm_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		dvdvmpop_buffer_state();
	}

	/* Destroy the stack itself. */
	dvdvmfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * dvdvmlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *dvdvmalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *dvdvmrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void dvdvmfree (void * ptr )
{
	free( (char *) ptr );	/* see dvdvmrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 198 "dvdvml.l"



